# Ports support for things that use Maven.
# NOTE: Currently doesn't support using other distfiles.

.if defined(USE_MAVEN)

BUILD_DEPENDS+=	mvn:${PORTSDIR}/devel/maven3
USE_JAVA=	yes
JAVA_VERSION?=	1.6+
# Not technically true, but no one uses Maven on non-Java software.
JAVA_RUN=	yes
JAVA_BUILD=	yes
MVN_ENV=	env MAVEN_REPOSITORY_HOME=${DISTDIR}/${_MVN_DIST}/repository
MVN=		${LOCALBASE}/bin/mvn
MVN_HOME=	${WRKDIR}/.maven_home
MVN_CMD=	${MVN_ENV} ${MVN} -Duser.home=${MVN_HOME}
MAVEN_WRKSRCS?=	${WRKSRC}

# Define the DIST_SUBDIR.  Must be at least ".".
_MVN_DIST=	.
.if defined(DIST_SUBDIR) && !empty(DIST_SUBDIR)
_MVN_DIST=	${DIST_SUBDIR}
.endif

# For use only with maven-makesum.
MVN_TMPDIST=	${WRKDIR}/.maven_tmpdist
MVN_FETCH_ARGS?=package dependency:go-offline
MVN_TMPFETCH=	${MVN_CMD} -Duser.home=${MVN_TMPDIST} ${MVN_FETCH_ARGS}

# Maven doesn't really offer a mechanism to generate a list of files without
# fetching them, so using Maven merges fetch into makesum.
#
# Note that we don't try to track the checksums for several reasons:
# - Maven uses metadata files that have date/time stamps that must be
#   quashed (done previously by Tools/generate_maven.sh).
# - There are potentially too many distfiles to track in ports, i.e. some
#   parts of Mk/ might use ${DISTFILES} in a way that is not scalable.
# - It's easier to update without also having to modify the port.
# - There are no external references for what the "correct" checksums
#   should be anyway, and once checked in, that value is known to us.
.if !target(maven-makesum)
maven-makesum:
	@${MAKE} clean do-extract
	${MKDIR} ${MVN_TMPDIST}
	@cd ${MASTERDIR} &&						\
		for srcdir in ${MAVEN_WRKSRCS}; do			\
			echo "cd $$srcdir && ${MVN_TMPFETCH}";		\
			cd $$srcdir && ${MVN_TMPFETCH};			\
		done
	cd ${MVN_TMPDIST}/.m2 && ${COPYTREE_SHARE} . ${DISTDIR}/${_MVN_DIST}
	@echo "Cleaning up ..."
	@${MAKE} clean
.endif # !target(maven-makesum)

# XXX Not sure why, but .for ... .endfor doesn't appear to work here.
.if !target(maven-build)
maven-build:
	${MKDIR} ${MVN_HOME}
	@for dir in ${MAVEN_WRKSRCS}; do				\
		echo "cd $$dir && ${MVN_CMD} package";			\
		cd $$dir && ${MVN_CMD} package;				\
	done
.endif # !target(maven-build)

.if defined(ALLOW_STANDARD_FETCH)
fetch:
	@true

makesum: maven-makesum
	@true
.endif # defined(ALLOW_STANDARD_FETCH)

.endif # defined(USE_MAVEN)
