#-*- tab-width: 4; -*-
# ex:ts=4

.if !defined(P4BIN)
P4BIN!=	which p4
.endif
.if empty(P4BIN)
P4BIN?=	/usr/local/bin/p4
.if !exists(${P4BIN})
P4BIN=	/usr/bin/p4
.endif
.endif

.if !target(all-remote-depends-list)
all-remote-depends-list:
	@all_depends_list=`${MAKE} all-depends-list`;				\
	for dir in $$all_depends_list; do					\
		if ! grep '^P4_DIR=' $$dir/Makefile >/dev/null 2>&1; then	\
			echo $$dir | sed -e "s,${PORTSDIR}/,,g";		\
		fi;								\
	done
.endif

# Except for the above variables, all of this file requires P4_DIR to be set
# in the port Makefile to have any effect.
.if defined(P4_DIR)

# P4 is needed for every phase but install, since the port needs various
# things, like revision, from p4.
FETCH_DEPENDS+=		p4:${PORTSDIR}/devel/p4
EXTRACT_DEPENDS+=	p4:${PORTSDIR}/devel/p4
PATCH_DEPENDS+=		p4:${PORTSDIR}/devel/p4
BUILD_DEPENDS+=		p4:${PORTSDIR}/devel/p4

.if !defined(IGNORE_P4_DIR)

.if !exists(${P4BIN})
.error "Could not find Perforce (${P4BIN})"
.endif

EXTRACT_ONLY=

## Check the Perforce environment and try to set up sane defaults.
.if empty(P4PORT) || !defined(P4PORT)
P4_ENV+=	P4PORT=perforce.eng.sldomain.com:1666
.endif
.if empty(P4CONFIG) || !defined(P4CONFIG)
P4_ENV+=	P4CONFIG=.p4config
.endif

# If the user doesn't provide P4TICKETS, set up P4PASSWD.  Note that the
# only reason this is needed is to obtain P4_VERSION.
P4_SET=		env ${P4_ENV} ${P4BIN} set | cut -d " " -f1
P4USER!=	${P4_SET} | awk -F= '/^P4USER=/ {print $$2}'; echo
P4TICKETS!=	${P4_SET} | awk -F= '/^P4TICKETS=/ {print $$2}'; echo
P4PASSWD!=	${P4_SET} | awk -F= '/^P4PASSWD=/ {print $$2}'; echo
.if empty(P4TICKETS) && empty(P4PASSWD) && !empty(P4USER)
# Auto-detect P4TICKETS if necessary.
_P4USER=	${P4USER:S/ //}
.if exists(/usr/home/${_P4USER}/.p4tickets)
P4TICKETS=	/usr/home/${_P4USER}/.p4tickets
.elif exists(/home/${_P4USER}/.p4tickets)
P4TICKETS=	/usr/home/${_P4USER}/.p4tickets
.elif exists(${HOME}/.p4tickets)
P4TICKETS=	${HOME}/.p4tickets
.endif
.if !empty(P4TICKETS)
P4_ENV+=	P4TICKETS=${P4TICKETS}
.endif
.endif

# At this point, the P4 environment must be completely setup.
P4=		env ${P4_ENV} ${P4BIN}

# If a P4 prefix is specified in the environment, use that.
.if !defined(P4_SOURCES)
P4_SOURCES!=${P4} client -o | awk '/^Root:/ {print $$2}'
.endif
.if !exists(${P4_SOURCES})
.error "Cannot find P4 source root at '${P4_SOURCES}'"
.endif

P4_HAVE_REV=	\#have
P4_SRCTREE=		${P4_SOURCES}/${P4_DIR}
P4_PATH=		${P4_SRCTREE}/...
P4_ORIGIN!=		cd ${P4_SRCTREE} && ${P4} where ${P4_PATH} | awk '{ print $$1 }'

# A port may specify additional trees to copy, if needed.  They will also
# contribute to P4_VERSION.
P4_OTHER_DIRS?=
P4_DIRS=	${P4_DIR} ${P4_OTHER_DIRS}

# The primary directory defines at least the initial work source directory.
WRKSRC?=		${WRKDIR}/${P4_DIR}

# Calculate the version as a function of the highest of P4_DIR and any other
# P4 directories specified by the build.
P4_VER_CMD=		${PORTSDIR}/Tools/spectra/p4_version
P4_VERSION!=	env ${P4_ENV} ${P4_VER_CMD} ${P4_SOURCES} ${P4_DIRS}; echo

# Not being able to look up the P4 version is a sure indicator that we have
# a failed Perforce setup.
.if empty(P4_VERSION)
.error "Unable to look up current P4 version of ${P4_DIRS}"
.endif

# Generate a packing list from the perforce sources.  This does not try to
# use Perforce to list the files, because we may want to package up new
# files for testing, without having to check them in.
#
# To use this, either set TMPPLIST to P4_PLISTFILE, or add the target as a
# dependency to post-install, and integrate it into TMPPLIST yourself.
#
# If possible, set P4_INSTPREFIX to an appropriate path relative to PREFIX.
#
# The P4_PLISTFILE can also be changed afterwards by specifying a
# post-p4-genplist target to do so.

P4_GENPLIST_DIR?=	${P4_SRCTREE}
P4_PLISTFILE=		${WRKDIR}/.p4_plist
P4_INSTPREFIX?=

.if !target(post-p4-genplist)
post-p4-genplist:
	@true
.endif # !target(post-p4-genplist)

.if !target(p4-genplist)
p4-genplist:
	${RM} -f ${P4_PLISTFILE}
	${FIND} ${P4_GENPLIST_DIR} \( -type f -o -type l \) | \
			${SED} -e 's,^${P4_GENPLIST_DIR},${P4_INSTPREFIX},g' >> ${P4_PLISTFILE}
	${FIND} ${P4_GENPLIST_DIR} -type d | \
		${SED} -e 's,^${P4_GENPLIST_DIR},@dirrm ${P4_INSTPREFIX},g' | \
		${SORT} -r >> ${P4_PLISTFILE}

.if !empty(TMPPLIST) && ${TMPPLIST} == ${P4_PLISTFILE}
post-install: post-p4-genplist
.endif
.endif # !target(p4-genplist)

# Unconditionally depend on p4-genplist for post-p4-genplist.
post-p4-genplist: p4-genplist


# Don't bother requiring checksums for Perforce backed files.  We want these
# ports to update & work just by changing the source files in Perforce.
.if !defined(EXT_DISTFILES)
NO_CHECKSUM=	yes

.if !target(do-fetch)
do-fetch:
	@true
.endif
.endif

# Show the files being copied to the work source by setting P4_VERBOSE.
.if defined(P4_VERBOSE)
P4_TAR_EXTRACT_ARGS?=	-xvpf
.else
P4_TAR_EXTRACT_ARGS?=	-xpf
.endif

# Extract target override.  Essentially just copies the Perforce source tree
# to the work source tree.
#
# XXX This can be removed if all Perforce-based builds are required to
#     separate object directory from source directory.
.if !target(do-extract)
do-extract:
	@${RM} -rf ${WRKDIR}
	@${MKDIR} ${WRKSRC}
.for dir in ${P4_DIR} ${P4_OTHER_DIRS}
	@echo "Copying ${P4_SOURCES}/${dir} to ${WRKSRC} ..."
	${TAR} -C ${P4_SOURCES} -cpf - ${dir} | \
			${TAR} -C ${WRKDIR} ${P4_TAR_EXTRACT_ARGS} -
.endfor
.endif

# Ruby gem specific modifications.
.if defined(USE_RUBYGEMS)
DISTNAME=	${PORTNAME}-${GEMVERSION}
# bsd.ruby.mk extracts the downloaded gem file, gives ports the chance to
# apply patches, generates a gemspec and then do-build builds the gemspec.
# Since the source is coming from perforce, all that's necessary is to
# directly build the source from perforce.
# TODO "rake gem/build" or "gem build <spec>"?  Currently, perforce/rubygem
#      ports build the gem in post-extract.
.if !target(do-build)
do-build:
.endif
.if !target(do-install)
do-install:
	cd ${BUILD_WRKSRC} && ${SETENV} ${GEM_ENV} ${RUBYGEMBIN} install \
	  ${RUBYGEM_ARGS} ${GEMFILES} -- --build-args ${CONFIGURE_ARGS}
.endif
.endif # defined(USE_RUBYGEMS)

.endif # !defined(IGNORE_P4_DIR)
.endif # defined(P4_DIR)
