--- ./libraries/libldap/cyrus.c.orig	2013-08-16 18:12:59.000000000 +0000
+++ ./libraries/libldap/cyrus.c	2013-10-10 00:13:22.605261748 +0000
@@ -57,6 +57,33 @@
 * Various Cyrus SASL related stuff.
 */
 
+static const char *sasl_option_on = "1";
+static const char *sasl_option_off = "0";
+
+static int ldap_sasl_getopt(
+	void *context,
+	const char *plugin_name,
+	const char *option,
+	const char **result,
+	unsigned *len)
+{
+	LDAP *ld = (LDAP *)context;
+	int ad_compat = (int)LDAP_BOOL_GET( &ld->ld_options,
+		LDAP_BOOL_SASL_AD_COMPAT );
+
+	if ( ld == NULL || plugin_name == NULL || result == NULL ||
+		strcmp(plugin_name, "GSSAPI") != 0 ||
+		strcmp(option, "ad_compat") != 0 ) {
+		return SASL_FAIL;
+	}
+
+	*result = ad_compat ? sasl_option_on : sasl_option_off;
+	if ( len ) {
+		*len = strlen(*result);
+	}
+	return SASL_OK;
+}
+
 static const sasl_callback_t client_callbacks[] = {
 #ifdef SASL_CB_GETREALM
 	{ SASL_CB_GETREALM, NULL, NULL },
@@ -66,6 +93,7 @@
 	{ SASL_CB_PASS, NULL, NULL },
 	{ SASL_CB_ECHOPROMPT, NULL, NULL },
 	{ SASL_CB_NOECHOPROMPT, NULL, NULL },
+	{ SASL_CB_GETOPT, ldap_sasl_getopt, NULL },
 	{ SASL_CB_LIST_END, NULL, NULL }
 };
 
@@ -321,6 +349,7 @@
 {
 	int rc;
 	sasl_conn_t *ctx;
+	sasl_callback_t *callback;
 
 	assert( lc->lconn_sasl_authctx == NULL );
 
@@ -334,15 +363,29 @@
 		return ld->ld_errno;
 	}
 
+	if ( lc->lconn_sasl_callbacks == NULL ) {
+		lc->lconn_sasl_callbacks =
+			(sasl_callback_t *) malloc( sizeof(client_callbacks) );
+		memcpy( lc->lconn_sasl_callbacks, client_callbacks,
+			sizeof(client_callbacks) );
+		for ( callback = lc->lconn_sasl_callbacks;
+			callback->id != SASL_CB_LIST_END;
+			callback++ ) {
+			callback->context = ld;
+		}
+	}
+
 #if SASL_VERSION_MAJOR >= 2
 	rc = sasl_client_new( "ldap", host, NULL, NULL,
-		client_callbacks, 0, &ctx );
+		lc->lconn_sasl_callbacks, 0, &ctx );
 #else
-	rc = sasl_client_new( "ldap", host, client_callbacks,
+	rc = sasl_client_new( "ldap", host, lc->lconn_sasl_callbacks,
 		SASL_SECURITY_LAYER, &ctx );
 #endif
 
 	if ( rc != SASL_OK ) {
+		free( lc->lconn_sasl_callbacks );
+		lc->lconn_sasl_callbacks = NULL;
 		ld->ld_errno = sasl_err2ldap( rc );
 		return ld->ld_errno;
 	}
@@ -359,6 +402,10 @@
 {
 	sasl_conn_t *ctx = lc->lconn_sasl_authctx;
 
+	if ( lc->lconn_sasl_callbacks != NULL ) {
+		free( lc->lconn_sasl_callbacks );
+		lc->lconn_sasl_callbacks = NULL;
+	}
 	if( ctx != NULL ) {
 		sasl_dispose( &ctx );
 		if ( lc->lconn_sasl_sockctx &&
@@ -976,6 +1023,10 @@
 			*(int *)arg = (int) LDAP_BOOL_GET(&ld->ld_options, LDAP_BOOL_SASL_NOCANON );
 			break;
 
+		case LDAP_OPT_X_SASL_AD_COMPAT:
+			*(int *)arg = (int) LDAP_BOOL_GET(&ld->ld_options, LDAP_BOOL_SASL_AD_COMPAT);
+			break;
+
 		case LDAP_OPT_X_SASL_USERNAME: {
 			int sc;
 			char *username;
@@ -1097,6 +1148,13 @@
 			LDAP_BOOL_SET(&ld->ld_options, LDAP_BOOL_SASL_NOCANON );
 		}
 		break;
+	case LDAP_OPT_X_SASL_AD_COMPAT:
+		if ( arg == LDAP_OPT_OFF ) {
+			LDAP_BOOL_CLR(&ld->ld_options, LDAP_BOOL_SASL_AD_COMPAT );
+		} else {
+			LDAP_BOOL_SET(&ld->ld_options, LDAP_BOOL_SASL_AD_COMPAT );
+		}
+		break;
 
 	case LDAP_OPT_X_SASL_SECPROPS: {
 		int sc;
